[−][src]Enum resources::InvalidBorrow
Error indicating that accessing the requested Resource in a Resources container
via get or get_mut methods would violate borrow rules.
Variants
Can't access mutably because the resource is accessed either immutably or mutably elsewhere.
Can't access immutably because the resource is accessed mutably elsewhere.