[][src]Struct resources::Entry

pub struct Entry<'a, T: Resource> { /* fields omitted */ }

A view into a specific Resource's entry in a Resources container, which may either be vacant or occupied.

This is returned by the entry method on Resources.

Methods

impl<'a, T: Resource> Entry<'a, T>[src]

pub fn or_insert(self, default: T) -> RefMut<'a, T>[src]

Ensures a resource is in the entry by inserting the given value if empty, and returns a mutable reference to the contained resource.

pub fn or_insert_with(self, default: impl FnOnce() -> T) -> RefMut<'a, T>[src]

Ensures a resource is in the entry by inserting the result of given function if empty, and returns a mutable reference to the contained resource.

pub fn and_modify(self, f: impl FnOnce(&mut T)) -> Self[src]

Provides in-place mutable access to an occupied entry before any potential inserts.

impl<'a, T: Resource + Default> Entry<'a, T>[src]

pub fn or_default(self) -> RefMut<'a, T>[src]

Ensures a resource is in the entry by inserting it's default value if empty, and returns a mutable reference to the contained resource.